@@ -1,9 +1,10 @@
+import logging
 import sys
 import time
-import curlify
 from datetime import datetime
 from datetime import timedelta
 
+import curlify
 import inforion.ionapi.model.inforlogin as inforlogin
 from inforion.ionapi.controller import *
 from inforion.ionapi.model import *
@@ -14,12 +15,8 @@ from inforion.logger.logger import get_logger
 
 # import inforion.ionapi.basic as inforlogin
 
-import logging
-
 # from logger import get_logger
 
-import inforion.ionapi.model.inforlogin as inforlogin
-
 # import inforion.ionapi.basic as inforlogin
 
 logger = get_logger("main", True)
@@ -102,12 +99,14 @@ def sendresults(url, _headers, data, timeout=65, stream=False):
                     r = "JSON Error"
                     logger.error(r)
             else:
-                if z < 5:
+                r = "Session Error " + str(z)
+                logger.error(r)
+                if z < 10:
                     logger.info(" Error try to get new session " + str(z) + "/5")
                     headers = inforlogin.reconnect()
                     time.sleep(10)
-                elif z == 5:
-                    sys.exit(0)
+                elif z == 10:
+                    raise SystemExit(r)
 
     except requests.exceptions.TooManyRedirects:
         logger.error("Too many redirects")
