@@ -9,6 +9,7 @@ import inforion.transformation.transform_special as ts
 import numpy as np
 import pandas as pd
 from inforion.logger.logger import get_logger
+from inforion.transformation.transform_error import TransformationError
 
 logger = get_logger("transform", True)
 
@@ -297,9 +298,3 @@ def clean(string):
     if str.endswith("]"):
         str = str[:-1]
     return str
-
-
-class TransformationError(Exception):
-    def __init__(self, message):
-        self.message = message
-        super().__init__(self.message)
